// https://doc.rust-lang.org/stable/rust-by-example/std_misc/file/read_lines.html
use std::fs::File;
use std::io::{self, BufRead};
use std::path::Path;


pub fn part_one() {
    if let Ok(lines) = read_lines("./input.txt") {

        let mut result = 0;

        for line in lines {
            result += parse_line(&line.unwrap());
        }

        println!("{}", result);
    }
}



fn read_lines<P>(filename: P) -> io::Result<io::Lines<io::BufReader<File>>>
where P: AsRef<Path>, {
    let file = File::open(filename)?;
    Ok(io::BufReader::new(file).lines())
}

fn parse_line(s: &str) -> u32{

    const RADIX: u32 = 10;
    
    let mut first_digit = 0;
    let mut last_digit = 0;

    for c in s.chars() {
        if c.is_digit(RADIX) {

            let digit = c.to_digit(RADIX).unwrap();

            if first_digit == 0 {
                first_digit = digit;
            }
            last_digit = digit;
            
        }
    }
    
    return first_digit * 10 + last_digit   
}